'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

var breakpoints = [{
  breakpoint: "xs",
  abbr: "",
  name: "Extra small",
  "min-width": "0px",
  container: ""
}, {
  breakpoint: "sm",
  abbr: "-sm",
  name: "Small",
  "min-width": "576px",
  container: "540px"
}, {
  breakpoint: "md",
  abbr: "-md",
  name: "Medium",
  "min-width": "768px",
  container: "720px"
}, {
  breakpoint: "lg",
  abbr: "-lg",
  name: "Large",
  "min-width": "992px",
  container: "960px"
}, {
  breakpoint: "xl",
  abbr: "-xl",
  name: "Extra large",
  "min-width": "1200px",
  container: "1140px"
}];
var colors = [{
  name: "blue",
  hex: "#007bff"
}, {
  name: "indigo",
  hex: "#6610f2"
}, {
  name: "purple",
  hex: "#6f42c1"
}, {
  name: "pink",
  hex: "#e83e8c"
}, {
  name: "red",
  hex: "#dc3545"
}, {
  name: "orange",
  hex: "#fd7e14"
}, {
  name: "yellow",
  hex: "#ffc107"
}, {
  name: "green",
  hex: "#28a745"
}, {
  name: "teal",
  hex: "#20c997"
}, {
  name: "cyan",
  hex: "#17a2b8"
}, {
  name: "white",
  hex: "#fff"
}, {
  name: "gray",
  hex: "#868e96"
}, {
  name: "gray-dark",
  hex: "#343a40"
}];
var json = {
  breakpoints: breakpoints,
  colors: colors,
  "theme-colors": [{
    name: "primary",
    hex: "#007bff"
  }, {
    name: "secondary",
    hex: "#868e96"
  }, {
    name: "success",
    hex: "#28a745"
  }, {
    name: "danger",
    hex: "#dc3545"
  }, {
    name: "warning",
    hex: "#ffc107"
  }, {
    name: "info",
    hex: "#17a2b8"
  }, {
    name: "light",
    hex: "#f8f9fa"
  }, {
    name: "dark",
    hex: "#343a40"
  }]
};
function dedupe(list) {
  if (!Array.isArray(list)) throw new Error("muse be list!");
  return Array.from(new Set(list));
}
function flatten(listOrItem) {
  var newList = [];
  if (Array.isArray(listOrItem)) {
    listOrItem.forEach(function (item) {
      newList = newList.concat(flatten(item));
    });
  } else newList.push(listOrItem);
  return newList;
}
function rclassnames(props) {
  var args = [];
  for (var _i = 1; _i < arguments.length; _i++) {
    args[_i - 1] = arguments[_i];
  }
  var clsList = dedupe(flatten(args).concat([props.className, props["class"]]).filter(function (x) {
    return x && typeof x === 'string';
  }).map(function (x) {
    return x && x.trim();
  }).join(' ').split(' '));
  if (!clsList.length) return;
  return clsList.join(' ');
}
var themes = json['theme-colors'].map(function (theme) {
  return theme.name;
});
var sizes = json['breakpoints'].map(function (x) {
  return x.breakpoint;
}).filter(function (x) {
  return x;
});
var inputTypes = [
'button',
'checkbox',
'color',
'date',
'datetime',
'datetime-local',
'email',
'file',
'hidden',
'image',
'month',
'number',
'password',
'radio',
'range',
'reset',
'search',
'submit',
'tel',
'text',
'time',
'url',
'week'];
function filterInputType(type) {
  if (type === void 0) {
    type = '';
  }
  if (inputTypes.includes(type)) return type;
}

function _extends$1() {
  _extends$1 = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends$1.apply(this, arguments);
}
function __rest$1(s, e) {
  var t = {};
  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }
  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}
function input(_a, wref) {
  var children = _a.children,
      _b = _a.disabled,
      disabled = _b === void 0 ? false : _b,
      _c = _a.textarea,
      textarea = _c === void 0 ? false : _c,
      _d = _a.readonly,
      readonly = _d === void 0 ? false : _d,
      _e = _a.type,
      type = _e === void 0 ? '' : _e,
  indeterminate = _a.indeterminate,
      props = __rest$1(_a, ["children", "disabled", "textarea", "readonly", "type", "indeterminate"]);
  var JSXEl = textarea ? 'textarea' : 'input';
  type = textarea ? '' : filterInputType(type) || 'text';
  var inputHTMLElRef = React.useRef(null);
  var _ref = wref || props.ref || React.useRef(null);
  return React.createElement(JSXEl, _extends$1({}, props, readonly && {
    readonly: readonly
  }, disabled && {
    disabled: true
  }, type && {
    type: type
  }, type === 'checkbox' && indeterminate !== undefined && {
    indeterminate: indeterminate
  }, {
    ref: function ref(el) {
      inputHTMLElRef.current = el;
      if (_ref) _ref.current = el;
      return el;
    },
    className: rclassnames(props, [disabled ? "disabled" : ''])
  }), children);
}

var Textarea = function Textarea(_a) {
  var props = __rest(_a, []);

  return React.createElement(input, _extends({}, props, {
    type: "textarea"
  }));
};

module.exports = Textarea;
